Bialkow input
=============

This directory contains `daophot` and `allstar` parameters from photometry
pipeline of Bialkow Observatory, created by Z. Kolaczkowski.

Those files are used by daophot_bialkow.py example, which bases on mentioned pipeline.

